install

Function install 

pub fn install(options: InstallOptions) -> Result<()>
Print a plan and return without creating even a lock file unless options.yes is true. Reinstall retains unselected integrations, except exact owned references that must move with the generated scripts during a layout migration.